@@ -7,9 +7,9 @@ extern unsigned char ltable[MAX_TABLES][MAX_TABLELEN];
 extern unsigned char rtable[MAX_TABLES][MAX_TABLELEN];
 extern unsigned char songorder[MAX_SONGS][MAX_CHN][MAX_SONGLEN+2];
 extern unsigned char pattern[MAX_PATT][MAX_PATTROWS*4+4];
-extern unsigned char songname[MAX_STR];
-extern unsigned char authorname[MAX_STR];
-extern unsigned char copyrightname[MAX_STR];
+extern char songname[MAX_STR];
+extern char authorname[MAX_STR];
+extern char copyrightname[MAX_STR];
 extern int pattlen[MAX_PATT];
 extern int songlen[MAX_SONGS][MAX_CHN];
 extern int highestusedpattern;
